pub struct Session { /* private fields */ }Expand description
Single RTP session, (1 sender, many receiver)
This can be used to publish a single RTP source and receive others. It manages a jitterbuffer for every remote ssrc and can generate RTCP reports.
Implementations
Sourceimpl Session
impl Session
pub fn new(ssrc: u32, clock_rate: u32, cname: String) -> Self
Sourcepub fn clock_rate(&self) -> u32
pub fn clock_rate(&self) -> u32
Clock rate of the RTP timestamp
Sourcepub fn recv_rtp(&mut self, rtp_packet: RtpPacket)
pub fn recv_rtp(&mut self, rtp_packet: RtpPacket)
Receive an RTP packet.
The session consumes the packet and puts in into a internal jitterbuffer to fix potential reordering.
pub fn pop_rtp(&mut self) -> Option<RtpPacket>
pub fn recv_rtcp(&mut self, packet: Packet<'_>)
Sourcepub fn write_rtcp_report(
&mut self,
dst: &mut [u8],
) -> Result<usize, RtcpWriteError>
pub fn write_rtcp_report( &mut self, dst: &mut [u8], ) -> Result<usize, RtcpWriteError>
Generate RTCP sender or receiver report packet.
This resets the internal received & lost packets counter for every receiver.